version 8.2
set logtype text

capture log close
log using "brazrloc/logs/rais-cnpjradic-cnae95.log", replace


// POPULATION FIRMS (CNPJ_RADIC)

forvalues i=1/10 {
  tempfile pop`i'
  local file = "aggcnpj_" + lower(char(64+`i'))
  use cnpj_radic ano mod_clas_cnae_95 if ano==1995 using "rais/base-agg/cnpjradic/`file'", clear
  label var mod_clas_cnae_95 "CNAE sector 1995 (annual mode)"
  drop ano
  sort cnpj_radic
  save `pop`i''
  }


// NATIONWIDE SAMPLE FIRMS

use identificad ano if ano>=1986 & ano<=1998 using "brazrloc/data/rais-cnpj-list-natl", clear  // rais-cnpj-list-natl.dta is extract from base catalog rais/base-cnpj/rais-catalog-cnpj
* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
sort cnpj_radic ano
by cnpj_radic ano: keep if _n==1

* check for balanced panel 1986-1998
sort cnpj_radic ano
by cnpj_radic: gen byte _currno = _n
egen byte _maxyrs = max(_currno), by(cnpj_radic)
drop _currno
gen byte _ind1995 = (ano==1995)
egen byte _indaliv95 = max(_ind1995), by(cnpj_radic)
drop _ind1995
tab _maxyrs _indaliv95
count if _indaliv95 & _maxyrs<13
gen byte indcnts13 = (_maxyrs == 13)
label var indcnts13 "Indic.: Presence 1986-98"
drop _indaliv95 _maxyrs
sort cnpj_radic ano

* CNAE 1995
forvalues i=1/10 {
  sort cnpj_radic
  merge cnpj_radic using `pop`i'', nokeep update
  qui count if _m==5
  if `r(N)'>0  STOP  // contradictory sector information
  drop _m
  }

sort cnpj_radic ano
save "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98", replace


// METROPOLITAN SAMPLE FIRMS

use identificad ano if ano>=1986 & ano<=1998 using "brazrloc/data/rais-cnpj-list-metro", clear  // rais-cnpj-list-metro.dta is extract from base catalog rais/base-cnpj/rais-catalog-cnpj
* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
sort cnpj_radic ano
by cnpj_radic ano: keep if _n==1

* check for balanced panel 1986-1998
sort cnpj_radic ano
by cnpj_radic: gen byte _currno = _n
egen byte _maxyrs = max(_currno), by(cnpj_radic)
drop _currno
gen byte _ind1995 = (ano==1995)
egen byte _indaliv95 = max(_ind1995), by(cnpj_radic)
drop _ind1995
tab _maxyrs _indaliv95
count if _indaliv95 & _maxyrs<13
gen byte indcnts13 = (_maxyrs == 13)
label var indcnts13 "Indic.: Presence 1986-98"
drop _indaliv95 _maxyrs
sort cnpj_radic ano

* CNAE 1995
forvalues i=1/10 {
  sort cnpj_radic
  merge cnpj_radic using `pop`i'', nokeep update
  qui count if _m==5
  if `r(N)'>0  STOP  // contradictory sector information
  drop _m
  }

sort cnpj_radic ano
save "brazrloc/data/rais-cnpjradic-cnae95-metro-86-98", replace


log close
