version 8.2
clear
set logtype text
set more off
set matsize 200
tempfile pia

capture mkdir "brazrloc/estmat/v4"
capture mkdir "brazrloc/estmat/v4/ext"
capture mkdir "brazrloc/tex/v4"
capture mkdir "brazrloc/tex/v4/ext"
capture mkdir "brazrloc/tex/v4/ext/corr"
capture mkdir "brazrloc/tex/v4/ext/summ"
capture mkdir "brazrloc/graphs/v4"
capture mkdir "brazrloc/graphs/v4/ext"

capture log close
log using "brazrloc/logs/compadv-data.log", replace


* DATA

use "brazaux/auxil/tariff-data", clear
merge niv50 year using "brazaux/auxil/comp-adv-niv50"
count if _m~=3 
if `r(N)'>0 {
  disp as err "Incomplete sector year match"
  STOP
  }
tab _m
drop _m
replace year = year + 1900
sort niv50 year
merge niv50 year using "brazaux/intl/balassa-compadv-niv50"
count if _m~=3 & niv50~=1 & niv50~=9 & year<=1998
if `r(N)'>0 {
  disp as err "Incomplete sector year match"
  STOP
  }
tab _m if niv50~=1 & niv50~=9 & year<=1998
drop _m


* FULL SECTOR LIST

preserve
tempfile complete
sort niv50 year
merge niv50 year using "brazrloc/auxil/niv50-agg"
tab _m
tab niv50 if _m==1 & year==1991  // note: no PIA information in 1991
tab niv50 if _m==1 & year~=1991  // note: no PIA information for sectors 1, 2, 3, 9, 32 in any year (and no information for sector 1530)
tab niv50 if _m==2 & year<1999   // note: RAIS information for sectors 1, 2, 3, 32 since 1995 (CNAE)
tab niv50 if _m==2 & year>1998   // RAIS information for all sectors past 1998
drop _m
qui do "rais/cnae/niv50.do"
label values niv50 niv50
fillin niv50 year
sort niv50 year
* variables in the list: balarank 90, balcadv 90, erp 90, log labor productivity change 95-90, cap_empl 90, indprown_pis 95
rename erp erp90
label var erp90 "Effective rate of protection 90" 
rename balcadv balcadv90
label var balcadv90 "Balassa comp. advantage 90"
by niv50: gen lnlpchg9890 = sqrt(sqrt(sqrt(exp(lnlp[_n+8])/exp(lnlp))))-1 if year==1990 & year[_n+8]==1998
label var lnlpchg9890 "Annual labor prod. change 90-98"
by niv50: gen indprown9895 = indprown_pis[_n+8] - indprown_pis[_n+5] if year==1990 & year[_n+8]==1998 & year[_n+5]==1995
label var indprown9895 "Private-job share change 95-98"
replace cap_empl = cap_empl/1000
rename cap_empl cap_empl90
label var cap_empl90 "Capital/workforce 90 [thd 94 R$]"
keep if year==1990
keep niv50 balarank balcadv erp cap_empl lnlpchg9890 indprown9895
decode niv50, gen(_secname)
replace _secname = "(" + string(balarank) + ") " + _secname
gen _rowname =  "q" + string(balarank) + "_" + string(niv50) + ":" + string(niv50)
replace _rowname = subinstr(_rowname,".","0",.)
drop niv50 balarank
order _secname balcadv erp cap_empl lnlpchg9890 indprown9895 _rowname
gsort -balcadv
drop _secname
order _rowname balcadv erp cap_empl lnlpchg9890 indprown9895
save "brazrloc/tex/v4/ext/summ/niv50en_tbl", replace
matload niv50en_tbl, p(brazrloc/tex/v4/ext/summ) missing(.) dropall
est2extlbl, addto(niv50en) intex(brazcomp/niv-cnae/niv50-en-systematic) p(brazrloc/tex/v4/ext/summ) replace dropall
est2tex niv50en, replace dropall preserve ready p(brazrloc/tex/v4/ext/summ) fancy digits(3)
restore


// SUBSEQUENT SECTOR DEFINITIONS: PARTIAL MINING AND MANUFACTURING LIST ONLY

drop if niv50==9  /* No observations for maintenance and installations */
drop if niv50==1  /* No observations of agriculture */
drop if year>1998 /* No observations after 1998 */
replace year = year - 1900


* TRANSITIONS BETWEEN COMPARATIVE ADVANTAGE RANKS *

* counts of quintile changes
preserve
keep niv50 year balarank ntxprank
sort niv50 year
by niv50: gen _balarank_chg = abs(balarank - balarank[_n-1])
by niv50: gen _ntxprank_chg = abs(ntxprank - ntxprank[_n-1])
count if _balarank_chg~=0
count if _balarank_chg>=2
count if _ntxprank_chg~=0
count if _ntxprank_chg>=2
summ _*
drop if year<90
count if _balarank_chg~=0
count if _balarank_chg>=2
count if _ntxprank_chg~=0
count if _ntxprank_chg>=2
summ _*
restore

* correlations
preserve
keep niv50 year expadv
rename expadv expadv_
reshape wide expadv_, i(niv50) j(year)
* corr expadv_*
corr2tex expadv_*, name(corr_expadv_yrs) p(brazrloc/tex/v4/ext/corr) replace
restore, preserve
keep niv50 year balcadv
rename balcadv balcadv_
reshape wide balcadv_, i(niv50) j(year)
* corr balcadv_*
corr2tex balcadv_*, name(corr_balcadv_yrs) p(brazrloc/tex/v4/ext/corr) replace
restore

* transitions
tsset niv50 year
xttrans ntxprank
xttrans ntxprank if year>=90
xttrans balarank
xttrans balarank if year>=90


* BAR GRAPHS: DECOMPOSITIONS OF COMPARATIVE ADVANTAGE CHANGES *

preserve
keep if year==90 | year==97
keep niv50 year balcadv braz_exp braz_tot wrld_exp wrld_tot
gsort year -balcadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
sort secnum
label var secnum "Sector (Nivel 50)"
gen s_braz =  braz_exp/braz_tot
gen s_world =  wrld_exp/wrld_tot
sort niv50 year
by niv50: gen del_balcadv = 100* (balcadv - balcadv[_n-1])/balcadv[_n-1] 
by niv50: gen del_sbraz = 100* (s_braz - s_braz[_n-1])/s_braz[_n-1] 
by niv50: gen del_sworld = - 100* (s_world - s_world[_n-1])/s_world[_n-1]
by niv50: gen del_error = - 100* (s_braz/s_braz[_n-1] - s_world/s_world[_n-1])*(s_world-s_world[_n-1])/s_world
gen _chk = del_balcadv - (del_sbraz + del_sworld) - del_error
qui summ _chk
if abs(`r(mean)')>1e-05  STOP
drop s_braz s_world _chk
keep if year==97
keep niv50 del* secnum
sort secnum
graph bar (asis) del_sbraz del_sworld del_error, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1990-97 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") label(3 "Interaction Residual") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-res-chg-90-97.eps", replace
gen del_sbraz_res = del_sbraz + (1/2) * del_error
gen del_sworld_res = del_sworld + (1/2) * del_error
graph bar (asis) del_sbraz_res del_sworld_res, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1990-97 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-chg-90-97.eps", replace
restore
more

preserve
keep if year==86 | year==97
keep niv50 year balcadv braz_exp braz_tot wrld_exp wrld_tot
gsort year -balcadv
gen _secnum = _n if year==86
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
sort secnum
label var secnum "Sector (Nivel 50)"
gen s_braz =  braz_exp/braz_tot
gen s_world =  wrld_exp/wrld_tot
sort niv50 year
by niv50: gen del_balcadv = 100* (balcadv - balcadv[_n-1])/balcadv[_n-1] 
by niv50: gen del_sbraz = 100* (s_braz - s_braz[_n-1])/s_braz[_n-1] 
by niv50: gen del_sworld = - 100* (s_world - s_world[_n-1])/s_world[_n-1]
by niv50: gen del_error = - 100* (s_braz/s_braz[_n-1] - s_world/s_world[_n-1])*(s_world-s_world[_n-1])/s_world
gen _chk = del_balcadv - (del_sbraz + del_sworld) - del_error
qui summ _chk
if abs(`r(mean)')>1e-05  STOP
drop s_braz s_world _chk
keep if year==97
keep niv50 del* secnum
sort secnum
graph bar (asis) del_sbraz del_sworld del_error, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1986-97 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") label(3 "Interaction Residual") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-res-chg-86-97.eps", replace
gen del_sbraz_res =  del_sbraz + (1/2) * del_error
gen del_sworld_res =  del_sworld + (1/2) * del_error
graph bar (asis) del_sbraz_res del_sworld_res, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1986-97 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-chg-86-97.eps", replace
restore
more

preserve
keep if year==90 | year==98
keep niv50 year balcadv braz_exp braz_tot wrld_exp wrld_tot
gsort year -balcadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
sort secnum
label var secnum "Sector (Nivel 50)"
gen s_braz =  braz_exp/braz_tot
gen s_world =  wrld_exp/wrld_tot
sort niv50 year
by niv50: gen del_balcadv = 100* (balcadv - balcadv[_n-1])/balcadv[_n-1] 
by niv50: gen del_sbraz = 100* (s_braz - s_braz[_n-1])/s_braz[_n-1] 
by niv50: gen del_sworld = - 100* (s_world - s_world[_n-1])/s_world[_n-1]
by niv50: gen del_error = - 100* (s_braz/s_braz[_n-1] - s_world/s_world[_n-1])*(s_world-s_world[_n-1])/s_world
gen _chk = del_balcadv - (del_sbraz + del_sworld) - del_error
qui summ _chk
if abs(`r(mean)')>1e-05  STOP
drop s_braz s_world _chk
keep if year==98
keep niv50 del* secnum
sort secnum
graph bar (asis) del_sbraz del_sworld del_error, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1990-98 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") label(3 "Interaction Residual") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-res-chg-90-98.eps", replace
gen del_sbraz_res =  del_sbraz + (1/2) * del_error
gen del_sworld_res =  del_sworld + (1/2) * del_error
graph bar (asis) del_sbraz_res del_sworld_res, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1990-98 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-chg-90-98.eps", replace
restore
more

preserve
keep if year==86 | year==98
keep niv50 year balcadv braz_exp braz_tot wrld_exp wrld_tot
gsort year -balcadv
gen _secnum = _n if year==86
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
sort secnum
label var secnum "Sector (Nivel 50)"
gen s_braz =  braz_exp/braz_tot
gen s_world =  wrld_exp/wrld_tot
sort niv50 year
by niv50: gen del_balcadv = 100* (balcadv - balcadv[_n-1])/balcadv[_n-1] 
by niv50: gen del_sbraz = 100* (s_braz - s_braz[_n-1])/s_braz[_n-1] 
by niv50: gen del_sworld = - 100* (s_world - s_world[_n-1])/s_world[_n-1]
by niv50: gen del_error = - 100* (s_braz/s_braz[_n-1] - s_world/s_world[_n-1])*(s_world-s_world[_n-1])/s_world
gen _chk = del_balcadv - (del_sbraz + del_sworld) - del_error
qui summ _chk
if abs(`r(mean)')>1e-05  STOP
drop s_braz s_world _chk
keep if year==98
keep niv50 del* secnum
sort secnum
graph bar (asis) del_sbraz del_sworld del_error, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1986-98 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") label(3 "Interaction Residual") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-res-chg-86-98.eps", replace
gen del_sbraz_res =  del_sbraz + (1/2) * del_error
gen del_sworld_res =  del_sworld + (1/2) * del_error
graph bar (asis) del_sbraz_res del_sworld_res, over(secnum) stack ytitle("Change in Balassa Comp. Adv. 1986-98 (%)") legend( label(1 "Chg. in Brazil's Export Sh.") label(2 "- Chg. in World Export Sh.") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/ext/balcadv-chg-86-98.eps", replace
restore
more


* DISPLAY ERP MEAN AND DISPERSION IN LOG FILE * 

preserve
collapse (mean) erp if niv50>=4, by(niv50 year) fast
gsort -erp
list if year==90
list if year==97
restore, preserve
collapse (mean) erp if niv50>=4, by(year) fast
gsort -erp
list if year==90
list if year==97
restore


* REGRESSIONS: COMPARATIVE ADVANTAGE *

foreach advtype in comp exp balc {
  xi: reg erp `advtype'adv i.year
  est2vec `advtype'pol, vars(`advtype'adv _Iyear_86 _Iyear_87 _Iyear_88 _Iyear_89 _Iyear_90 _Iyear_91 _Iyear_92 _Iyear_93 _Iyear_94 _Iyear_95 _Iyear_96 _Iyear_97 _Iyear_98 _cons) e(N ll r2) name(erp_allyrs)
  test _Iyear_87 = _Iyear_88 = _Iyear_89 = _Iyear_90 = _Iyear_91 = _Iyear_92 = _Iyear_93 = _Iyear_94 = _Iyear_95 = _Iyear_96 = _Iyear_97 = _Iyear_98 = 0
  est2vec `advtype'pol, r(chi2 F p df) name(erp_allyrs)
  xi: reg tarfoutp `advtype'adv i.year
  est2vec `advtype'pol, addto(`advtype'pol) name(tarfoutp_allyrs)
  test _Iyear_87 = _Iyear_88 = _Iyear_89 = _Iyear_90 = _Iyear_91 = _Iyear_92 = _Iyear_93 = _Iyear_94 = _Iyear_95 = _Iyear_96 = _Iyear_97 = _Iyear_98 = 0
  est2vec `advtype'pol, raddto(`advtype'pol) name(tarfoutp_allyrs)
  xi: reg tarfintm `advtype'adv i.year
  est2vec `advtype'pol, addto(`advtype'pol) name(tarfintm_allyrs)
  test _Iyear_87 = _Iyear_88 = _Iyear_89 = _Iyear_90 = _Iyear_91 = _Iyear_92 = _Iyear_93 = _Iyear_94 = _Iyear_95 = _Iyear_96 = _Iyear_97 = _Iyear_98 = 0
  est2vec `advtype'pol, raddto(`advtype'pol) name(tarfintm_allyrs)
  foreach yr in 86 90 94 97 {
    xi: reg erp `advtype'adv i.year if year==`yr'
    est2vec `advtype'pol, addto(`advtype'pol) name(erp_19`yr')
    est2vec `advtype'pol, raddto(`advtype'pol) name(erp_19`yr')
    xi: reg tarfoutp `advtype'adv i.year if year==`yr'
    est2vec `advtype'pol, addto(`advtype'pol) name(tarfoutp_19`yr')
    est2vec `advtype'pol, raddto(`advtype'pol) name(tarfoutp_19`yr')
    xi: reg tarfintm `advtype'adv i.year if year==`yr'
    est2vec `advtype'pol, addto(`advtype'pol) name(tarfintm_19`yr')
    est2vec `advtype'pol, raddto(`advtype'pol) name(tarfintm_19`yr')
    }

  xi: xtreg `advtype'adv tarfoutp tarfintm i.year, i(niv50)
  est2vec `advtype'advreg, vars(tarfoutp tarfintm _Iyear_86 _Iyear_87 _Iyear_88 _Iyear_89 _Iyear_90 _Iyear_91 _Iyear_92 _Iyear_93 _Iyear_94 _Iyear_95 _Iyear_96 _Iyear_97 _Iyear_98 _cons) e(N r2 r2_o r2_w r2_b) name(xtallyrs)
  test _Iyear_87 = _Iyear_88 = _Iyear_89 = _Iyear_90 = _Iyear_91 = _Iyear_92 = _Iyear_93 = _Iyear_94 = _Iyear_95 = _Iyear_96 = _Iyear_97 = _Iyear_98 = 0
  est2vec `advtype'advreg, r(chi2 F p df) name(xtallyrs)
  xtreg `advtype'adv tarfoutp tarfintm _Iyear_91 _Iyear_92 _Iyear_93 _Iyear_94 _Iyear_95 _Iyear_96 _Iyear_97 _Iyear_98 if year>=90, i(niv50)
  est2vec `advtype'advreg, addto(`advtype'advreg) name(xtyrs90_98)
  test _Iyear_91 = _Iyear_92 = _Iyear_93 = _Iyear_94 = _Iyear_95 = _Iyear_96 = _Iyear_97 = _Iyear_98 = 0
  est2vec `advtype'advreg, raddto(`advtype'advreg) name(xtyrs90_98)
  predict `advtype'advfe, u  /* Revealed sector-fixed comparative advantage, controlling for product and input tariffs */
  replace `advtype'advfe = `advtype'advfe + _b[_cons]
  xi: reg `advtype'adv tarfoutp tarfintm i.year
  est2vec `advtype'advreg, addto(`advtype'advreg) name(regallyrs)
  test _Iyear_87 = _Iyear_88 = _Iyear_89 = _Iyear_90 = _Iyear_91 = _Iyear_92 = _Iyear_93 = _Iyear_94 = _Iyear_95 = _Iyear_96 = _Iyear_97 = _Iyear_98 = 0
  est2vec `advtype'advreg, raddto(`advtype'advreg) name(regallyrs)
  xi: reg `advtype'adv tarfoutp tarfintm i.year if year>=90
  est2vec `advtype'advreg, addto(`advtype'advreg) name(regyrs90_98)
  test _Iyear_91 = _Iyear_92 = _Iyear_93 = _Iyear_94 = _Iyear_95 = _Iyear_96 = _Iyear_97 = _Iyear_98 = 0
  est2vec `advtype'advreg, raddto(`advtype'advreg) name(regyrs90_98)
  foreach yr in 86 90 94 97 {
    xi: reg `advtype'adv erp tarfoutp tarfintm i.year if year==`yr'
    est2vec `advtype'advreg, addto(`advtype'advreg) name(yr19`yr')
    est2vec `advtype'advreg, raddto(`advtype'advreg) name(yr19`yr')
    }

  * save matrices
  preserve
  foreach type in b se e r {
    matsave `advtype'pol_`type', replace p(brazrloc/estmat/v4/ext) dropall
    matsave `advtype'advreg_`type', replace p(brazrloc/estmat/v4/ext) dropall
    }
  restore

  } /* close `advtype' loop */


* CORRELATIONS: BETWEEN COMPARATIVE ADVANTAGE RANKS *

* corr compadv compadv_trfadj expadv balcadv
corr2tex compadv compadv_trfadj compadvfe expadv expadvfe balcadv balcadvfe, name(corr_adv) p(brazrloc/tex/v4/ext/corr) replace
* bysort year: corr compadv compadv_trfadj compadvfe expadv expadvfe


* TABLES: COMPARATIVE ADVANTAGE PROFILES *

preserve
keep if year==90 | year==97
keep niv50 year balcadv balcadvfe expadvfe
gsort year -balcadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename balcadv balcadv_
rename expadvfe expadvfe_
rename balcadvfe balcadvfe_
reshape wide balcadv_ expadvfe_ balcadvfe_, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected balcadv_90 balcadvfe_90 expadvfe_90 secnum, ytitle("Comparative Advantage Measures") xlabel(#31, valuelabel) legend( label(1 "Balassa Comp. Adv. 90") label(2 "Balassa Comp. Adv. FE") label(3 "Net Exports Adv. FE") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/balcadv-expadv-fe-90.eps", replace
restore
more

preserve
keep if year==90 | year==97
keep niv50 year expadv compadvfe expadvfe
gsort year -expadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename expadv expadv_
rename compadvfe compadvfe_
rename expadvfe expadvfe_
reshape wide expadv_ compadvfe_ expadvfe_, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected expadv_90 compadvfe_90 expadvfe_90 secnum, ytitle("Comparative Advantage Measures") xlabel(#31, valuelabel) legend( label(1 "Net Exports Comp. Adv. 90") label(2 "PPI World/WPI Brazil FE") label(3 "Net Exports Comp. Adv. FE") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/expadv-compadv-fe-90.eps", replace
restore
more

preserve
keep if year==90
keep niv50 year balcadv expadv
gsort year -balcadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename balcadv balcadv_
rename expadv expadv_
reshape wide balcadv expadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected balcadv_90 expadv_90 secnum, ytitle("Balsassa and Net Exports Comp. Advantage") xlabel(#31, valuelabel) legend( label(1 "Balassa Comp. Adv. 90") label(2 "Net Exp. Cmp. Adv. 90") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/balcadv-90.eps", replace
restore
more

preserve
keep if year==90
keep niv50 year balcadv expadv
replace balcadv = (balcadv-1)/10 + 1  // turn slope by 10 around the y=1 point
gsort year -balcadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename balcadv balcadv_
rename expadv expadv_
reshape wide balcadv expadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected balcadv_90 expadv_90 secnum, ytitle("Balsassa and Net Exports Comp. Advantage") xlabel(#31, valuelabel) legend( label(1 "Balassa Adv. 90 (turned by 10 at 1)") label(2 "Net Exp. Cmp. Adv. 90") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/balcadv-turned-90.eps", replace
restore
more

preserve
keep if year==90
keep niv50 year compadv expadv
gsort year -expadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename compadv compadv_
rename expadv expadv_
reshape wide compadv expadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected expadv_90 compadv_90 secnum, ytitle("Net export based Comparative Advantage") xlabel(#31, valuelabel) legend( label(1 "Net Exports Comp. Adv. 90") label(2 "PPI World/WPI Brazil 1990") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/expadv-90.eps", replace
restore
more

preserve
keep if year==90 | year==93 | year==97
keep niv50 year balcadv*
gsort year -balcadvfe
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename balcadv balcadv_
drop balcadvfe
reshape wide balcadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected balcadv_90 balcadv_93 balcadv_97 secnum, ytitle("Balassa Comparative Advantage") xlabel(#31, valuelabel) legend( label(1 "Balassa Comp. Adv. 90") label(2 "Balassa Comp. Adv. 93") label(3 "Balassas Comp. Adv. 97") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/balcadv-90-97.eps", replace
restore
more

preserve
keep if year==90 | year==93 | year==97
keep niv50 year tarfoutp expadv
gsort year -expadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename expadv expadv_
reshape wide tarfoutp expadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected expadv_90 expadv_93 expadv_97 secnum, ytitle("Net export based Comparative Advantage") xlabel(#31, valuelabel) legend( label(1 "Net Exports Comp. Adv. 90") label(2 "Net Exports Comp. Adv. 93") label(3 "Net Exports Comp. Adv. 97") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/expadv-90-97.eps", replace
restore
more

preserve
keep if year==90 | year==97
keep niv50 year balcadv balcadvfe
gsort year -balcadvfe
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename balcadv balcadv_
rename balcadvfe balcadvfe_
reshape wide balcadv_ balcadvfe_, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected balcadv_90 balcadv_97 balcadvfe_90 secnum, ytitle("Balassa Comparative Advantage") xlabel(#31, valuelabel) legend( label(1 "Balassa Comp. Adv. 90") label(2 "Balassa Comp. Adv. 97") label(3 "Balassa Comp. Adv. FE") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/balcadvfe-90-97.eps", replace
restore
more

preserve
keep if year==90 | year==97
keep niv50 year tarfoutp expadv expadvfe
gsort year -expadvfe
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename expadv expadv_
rename expadvfe expadvfe_
reshape wide tarfoutp_ expadv_ expadvfe_, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected expadv_90 expadv_97 expadvfe_90 secnum, ytitle("Net exports based Comparative Advantage") xlabel(#31, valuelabel) legend( label(1 "Net Exports Comp. Adv. 90") label(2 "Net Exports Comp. Adv. 97") label(3 "Net Exports Comp. Adv. FE") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/expadvfe-90-97.eps", replace
restore
more

preserve
keep if year==86
keep niv50 year tarfoutp balcadv
gsort year -balcadv
gen _secnum = _n if year==86
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename balcadv balcadv_
reshape wide tarfoutp balcadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected balcadv_86 secnum, yaxis(1) || connected tarfoutp_86 secnum, yaxis(2) ||, ytitle("Balassa Comparative Advantage", axis(1)) ytitle("Tariff Level", axis(2)) xtitle("Sector (Nivel 50)") xlabel(#31, valuelabel) ylabel(0 1 3(3)15, axis(1)) ylabel(0(.1)1, axis(2)) legend( label(1 "Balassa Comp. Adv. 86") label(2 "Product Tariffs 86") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T O) */ 
graph export "brazrloc/graphs/v4/ext/balcadv-tarif-86.eps", replace
restore
more

preserve
keep if year==90
keep niv50 year tarfoutp balcadv
gsort year -balcadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename balcadv balcadv_
reshape wide tarfoutp balcadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected balcadv_90 secnum, yaxis(1) || connected tarfoutp_90 secnum, yaxis(2) ||, ytitle("Balassa Comparative Advantage", axis(1)) ytitle("Tariff Level", axis(2)) xtitle("Sector (Nivel 50)") xlabel(#31, valuelabel) ylabel(0 1 3(3)15, axis(1)) ylabel(0(.1)1, axis(2)) legend( label(1 "Balassa Comp. Adv. 90") label(2 "Product Tariffs 90") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T O) */ 
graph export "brazrloc/graphs/v4/ext/balcadv-tarif-90.eps", replace
restore
more

preserve
keep if year==90
keep niv50 year tarfoutp expadv
gsort year -expadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename expadv expadv_
reshape wide tarfoutp expadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected expadv_90 secnum, yaxis(1) || connected tarfoutp_90 secnum, yaxis(2) ||, ytitle("Balassa Comparative Advantage", axis(1)) ytitle("Tariff Level", axis(2)) xtitle("Sector (Nivel 50)") xlabel(#31, valuelabel) ylabel(0 1 3(3)15, axis(1)) ylabel(0(.1)1, axis(2)) legend( label(1 "Net Exports Comp. Adv. 90") label(2 "Product Tariffs 90") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T O) */ 
graph export "brazrloc/graphs/v4/ext/expadv-tarif-90.eps", replace
restore
more

preserve
keep if year==90 | year==93 | year==97
keep niv50 year tarfoutp compadv
gsort year -compadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename compadv compadv_
reshape wide tarfoutp compadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected compadv_90 compadv_93 compadv_97 secnum, ytitle("Comparative Advantage (rel. to mean PPI ratio)") xlabel(#31, valuelabel) legend( label(1 "PPI World/WPI Brazil 1990") label(2 "PPI World/WPI Brazil 1993") label(3 "PPI World/WPI Brazil 1997") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/compadv-90-97.eps", replace
restore
more

preserve
keep if year==90
keep niv50 year tarfoutp compadv
gsort year tarfoutp
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename compadv compadv_
reshape wide tarfoutp compadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected tarfoutp_90 compadv_90 secnum, ytitle("Comparative Advantage (rel. to mean PPI ratio)") xlabel(#31, valuelabel) legend( label(1 "Product Tariffs 1990") label(2 "PPI World/WPI Brazil 1990") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/compadv-tarif-90.eps", replace
restore
more

preserve
keep if year==90 | year==93 | year==97
keep niv50 year tarfoutp compadv_trfadj
gsort year -compadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename compadv compadv_
reshape wide tarfoutp compadv, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected compadv_90 compadv_93 compadv_97 secnum, ytitle("Comparative Advantage (rel. to mean PPI ratio)") xlabel(#31, valuelabel) legend( label(1 "Adj. PPI World/WPI Brazil 90") label(2 "Adj. PPI World/WPI Brazil 93") label(3 "Adj. PPI World/WPI Brazil 97") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/compadv-adj-90-97.eps", replace
restore
more

preserve
keep if year==90 | year==97
keep niv50 year tarfoutp compadv expadvfe
gsort year -expadv
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
rename compadv compadv_
rename expadvfe expadvfe_
reshape wide tarfoutp_ compadv_ expadvfe_, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected compadv_90 compadv_97 expadvfe_90 secnum, ytitle("Comparative Advantage (rel. to mean PPI ratio)") xlabel(#31, valuelabel) legend( label(1 "PPI World/WPI Brazil 90") label(2 "PPI World/WPI Brazil 97") label(3 "Net Exports Comp. Adv. FE") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/compadvadj-expadvfe-90-97.eps", replace
restore
more


* TRADE BALANCE AND CURRENT ACCOUNT FROM NATIONAL ACCOUNTS

* from ca-us/prep-country.do
local country "brazil"
insheet using "ca-us/gdf-ifs/ifs/`country'.csv", clear comma nonames
local yr 1944
forvalues i = 10/69 {
  qui tostring v`i', replace force 
  local yr = `yr' + 1
  local yr = v`i'[1]
  rename v`i' yr`yr'
  }
rename v1 cdrom_scale
rename v2 units
rename v3 scale
rename v4 countryname
rename v5 database
rename v6 seriescode
rename v7 descriptor 
rename v8 tablestub
rename v9 midheader
drop if seriescode=="" | seriescode=="SERIESCODE"
duplicates drop
reshape long yr, i(cdrom_scale units scale countryname database seriescode descriptor tablestub midheader) j(year)
generate value = real(yr)
drop yr
keep if year>=1986
desc
gen varname =  subinstr(seriescode,"..",".",.)
qui replace varname =  subinstr(varname,"..",".",.)
qui replace varname =  subinstr(varname,"..",".",.)
qui replace varname =  subinstr(varname ,".","_",.)
qui replace varname =  substr(varname,1,length(varname)-1) if substr(varname,-1,1)=="_"
qui replace varname =  substr(varname,4,.)
order seriescode varname
qui keep if varname=="90C_ZF" | varname=="98C_ZF" | varname=="99B_ZF" | varname=="98_N_ZF" | varname=="99A_ZF"
keep varname year countryname cdrom_scale units value 
rename cdrom_scale scale
reshape wide scale units value, i(countryname year) j(varname) string
* from ca-us/redefine.do
gen gdp = value99B_ZF/real(lower(scale99B_ZF))
label var gdp "GDP (nat. curr.)"
gen gnp = value99A_ZF/real(lower(scale99A_ZF))
label var gdp "GNP (nat. curr.)"
gen trdvol = value90C_ZF/real(lower(scale90C_ZF)) + value98C_ZF/real(lower(scale98C_ZF))
label var trdvol "Trade volume (nat. curr.)"
gen tb = value90C_ZF/real(lower(scale90C_ZF)) - value98C_ZF/real(lower(scale98C_ZF))
label var trdvol "Trade balance (nat. curr.)"
gen ca = tb + value98_N_ZF/real(lower(scale98_N_ZF))
label var ca "Current account (nat. curr.)"
gen trdvol_gdp = trdvol/gdp
label var trdvol_gdp "Trade Volume per GDP"
gen ca_gnp = ca/gnp
label var ca_gnp "Current Account per GNP"
gen tb_gdp = tb/gdp
label var tb_gdp "Trade Balance per GDP"
keep countryname year gdp gnp trdvol tb ca trdvol_gdp ca_gnp tb_gdp
* graph
keep if year>=1991 & year<=2002
label var year "Calendar Year"
graph twoway connected trdvol_gdp tb_gdp year, ytitle("Trade Volume and Trade Balance per GDP") xlabel(1990 1991(2)2003) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/tb-ca-91-02.eps", replace
more

log close
