version 8.2
clear
set logtype text
set more off
set matsize 200
tempfile pia

capture mkdir "brazrloc/tex/v4"
capture mkdir "brazrloc/tex/v4/ext"
capture mkdir "brazrloc/tex/v4/ext/summ"

capture log close
log using "brazrloc/logs/data-by-sec.log", replace

// SUBSECTOR IBGE DATA (BRAZILIAN PRIME-AGE MALES AS WEIGHTS FOR EXPORTER STATUS)

use wid ano identificad subs_ibge sexo fx_etaria if ano<=1998 using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
drop sexo fx_etaria
rename ano year
sort wid year 

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.

* merge aggregate sector and comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balarank
rename subsibge subs_ibge
rename balcadv subs_balcadv

* merge additional sector information
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis subs_indprown_pis_95 subs_dollar subs_ppieu subs_ppinam

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge export status information by firm
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year
rename indexp firm_indexp

collapse (mean) subs_balcadv firm_indexp subs_tarfoutp subs_tarfintm subs_reffpen, by(subs_ibge)
label var subs_balcadv  "Balassa (1965) comp. advantage"
label var firm_indexp   "Mean Export Status (job weight)"
label var subs_tarfoutp "Ann. Sectoral Output Tariff"
label var subs_tarfintm "Ann. Sectoral Intm. Input Tariff"
label var subs_reffpen  "Ramos: Eff. Penetr. of Sector"

save "brazrloc/tex/v4/ext/summ/subs_natlmaleprime_tbl", replace
matload subs_natlmaleprime_tbl, p(brazrloc/tex/v4/ext/summ) missing(.) dropall rowname(subs_ibge)
qui label save ibge using "brazrloc/tex/v4/ext/summ/ibge", replace
est2tex subs_natlmaleprime, replace dropall preserve ready vallabel(ibge) p(brazrloc/tex/v4/ext/summ) fancy digits(3)

log close
