version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/graphs/v4/natl"
capture mkdir "brazrloc/tex/v4/natl"
capture mkdir "brazrloc/graphs/v4/natl/laborstats"
capture mkdir "brazrloc/tex/v4/natl/laborstats"

capture mkdir "brazrloc/graphs/v4/natl-maleprime"
capture mkdir "brazrloc/tex/v4/natl-maleprime"
capture mkdir "brazrloc/graphs/v4/natl-maleprime/laborstats"
capture mkdir "brazrloc/tex/v4/natl-maleprime/laborstats"

capture mkdir "brazrloc/graphs/v4/metromale"
capture mkdir "brazrloc/tex/v4/metromale"
capture mkdir "brazrloc/graphs/v4/metromale/laborstats"
capture mkdir "brazrloc/tex/v4/metromale/laborstats"

capture mkdir "brazrloc/graphs/v4/metromale-prime"
capture mkdir "brazrloc/tex/v4/metromale-prime"
capture mkdir "brazrloc/graphs/v4/metromale-prime/laborstats"
capture mkdir "brazrloc/tex/v4/metromale-prime/laborstats"


capture log close
log using "brazrloc/logs/labmkt-stats.log", replace


// RAIS: METROPOLITAN MALE WORKERS, 5-PERCENT SAMPLE

* METROPOLITAN PRIME-AGE MALES, ANNUAL LABOR MARKET TRANSITIONS 1986-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1986 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators by year
mat labmkttrns_86_98_tbl = J(6,5,.)
matrix colnames labmkttrns_86_98_tbl = indsamefrm indsamemet indothrmun indretired indunacc
preserve
local yrrow 0
foreach year in 1986 1988 1990 1992 1994 1996 {
  local yrrow = `yrrow' + 1
  matname labmkttrns_86_98_tbl `year', rows(`yrrow') explicit
  restore, preserve
  keep if year==`year' | year==`year'+1
  gen int _retires = year if caus_desl_tc==7
  gen int _dies = year if caus_desl_tc==8
  egen int _retiryr = min(_retires), by(wid)
  egen int _deathyr = min(_dies), by(wid)
  drop _retires _dies caus_desl_tc
  // mutually exclusive and exhaustive labor market experience indicators
  * same firm, including regional transfers
  by wid: gen byte indsamefrm = ( year==`year' | (cnpj_radic==cnpj_radic[_n-1] & year==`year'+1) )
  * different firm but same metropolitan area
  by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & (rm==rm[_n-1] & year==`year'+1) ) 
  * different firm and different metropolitan area, excludes regional transfers within firm
  by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & (rm~=rm[_n-1] & year==`year'+1) )
  * no employment, but prior retirement or death reported, or worker past retirement age in last observed job
  by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 ) ) )
  * unaccounted
  by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
  egen _chk = rsum(ind*)
  qui count if _chk~=1
  if `r(N)'>0  STOP  // indicators not mutually exclusive
  foreach var in indsamefrm indsamemet indothrmun indretired indunacc {
    qui summ `var', meanonly
    mat labmkttrns_86_98_tbl[`yrrow',colnumb(labmkttrns_86_98_tbl,"`var'")]=`r(mean)'
    }
  }
restore
matsave labmkttrns_86_98_tbl, p(brazrloc/tex/v4/metromale-prime/laborstats) replace dropall
gen int year = real(_rowname)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = _rowname + "-`yr1'" if _rowname=="19`yr'"
  }
order year

* report
graph bar (mean) indsamefrm indsamemet indothrmun indunacc, over(_rowname) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale-prime/laborstats/labmkttrns-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind*, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale-prime/laborstats) name(labmkttrns_86_98) fancy replace over nolog
restore

* METROPOLITAN PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1986 | ano>1993

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only prime-age workers with employment in metropolitan area on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm=="" | fx_etaria>7 ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1986 | (cnpj_radic==cnpj_radic[_n-1] & year==1987) | (cnpj_radic==cnpj_radic[_n-2] & year==1988) | (cnpj_radic==cnpj_radic[_n-3] & year==1989) | (cnpj_radic==cnpj_radic[_n-4] & year==1990) | (cnpj_radic==cnpj_radic[_n-5] & year==1991) | (cnpj_radic==cnpj_radic[_n-6] & year==1992) | (cnpj_radic==cnpj_radic[_n-7] & year==1993) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1987) | (rm==rm[_n-2] & year==1988) | (rm==rm[_n-3] & year==1989) | (rm==rm[_n-4] & year==1990) | (rm==rm[_n-5] & year==1991) | (rm==rm[_n-6] & year==1992) | (rm==rm[_n-7] & year==1993) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1987) | (rm~=rm[_n-2] & year==1988) | (rm~=rm[_n-3] & year==1989) | (rm~=rm[_n-4] & year==1990) | (rm~=rm[_n-5] & year==1991) | (rm~=rm[_n-6] & year==1992) | (rm~=rm[_n-7] & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1986 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1987) | (rm~=rm[_n-2] & year==1988) | (rm~=rm[_n-3] & year==1989) | (rm~=rm[_n-4] & year==1990) | (rm~=rm[_n-5] & year==1991) | (rm~=rm[_n-6] & year==1992) | (rm~=rm[_n-7] & year==1993) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale-prime/laborstats/labmktexp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale-prime/laborstats) name(labmktexp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale-prime/laborstats) name(labmktexp_86_93_sd) fancy replace over nolog
restore

* METROPOLITAN PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1990 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only prime-age workers with employment in metropolitan area on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm=="" | fx_etaria>7 ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1990 | (cnpj_radic==cnpj_radic[_n-1] & year==1991) | (cnpj_radic==cnpj_radic[_n-2] & year==1992) | (cnpj_radic==cnpj_radic[_n-3] & year==1993) | (cnpj_radic==cnpj_radic[_n-4] & year==1994) | (cnpj_radic==cnpj_radic[_n-5] & year==1995) | (cnpj_radic==cnpj_radic[_n-6] & year==1996) | (cnpj_radic==cnpj_radic[_n-7] & year==1997) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1991) | (rm==rm[_n-2] & year==1992) | (rm==rm[_n-3] & year==1993) | (rm==rm[_n-4] & year==1994) | (rm==rm[_n-5] & year==1995) | (rm==rm[_n-6] & year==1996) | (rm==rm[_n-7] & year==1997) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1991) | (rm~=rm[_n-2] & year==1992) | (rm~=rm[_n-3] & year==1993) | (rm~=rm[_n-4] & year==1994) | (rm~=rm[_n-5] & year==1995) | (rm~=rm[_n-6] & year==1996) | (rm~=rm[_n-7] & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1990 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1991) | (rm~=rm[_n-2] & year==1992) | (rm~=rm[_n-3] & year==1993) | (rm~=rm[_n-4] & year==1994) | (rm~=rm[_n-5] & year==1995) | (rm~=rm[_n-6] & year==1996) | (rm~=rm[_n-7] & year==1997) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale-prime/laborstats/labmktexp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale-prime/laborstats) name(labmktexp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale-prime/laborstats) name(labmktexp_90_97_sd) fancy replace over nolog
restore

* METROPOLITAN PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1994-2001

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1994 | ano>2001

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only prime-age workers with employment in metropolitan area on Dec 31, 1994
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm=="" | fx_etaria>7 ) & ano==1994 )  // mark worker 1994 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1994 | (cnpj_radic==cnpj_radic[_n-1] & year==1995) | (cnpj_radic==cnpj_radic[_n-2] & year==1996) | (cnpj_radic==cnpj_radic[_n-3] & year==1997) | (cnpj_radic==cnpj_radic[_n-4] & year==1998) | (cnpj_radic==cnpj_radic[_n-5] & year==1999) | (cnpj_radic==cnpj_radic[_n-6] & year==2000) | (cnpj_radic==cnpj_radic[_n-7] & year==2001) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1995) | (rm==rm[_n-2] & year==1996) | (rm==rm[_n-3] & year==1997) | (rm==rm[_n-4] & year==1998) | (rm==rm[_n-5] & year==1999) | (rm==rm[_n-6] & year==2000) | (rm==rm[_n-7] & year==2001) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1995) | (rm~=rm[_n-2] & year==1996) | (rm~=rm[_n-3] & year==1997) | (rm~=rm[_n-4] & year==1998) | (rm~=rm[_n-5] & year==1999) | (rm~=rm[_n-6] & year==2000) | (rm~=rm[_n-7] & year==2001) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1994 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1995) | (rm~=rm[_n-2] & year==1996) | (rm~=rm[_n-3] & year==1997) | (rm~=rm[_n-4] & year==1998) | (rm~=rm[_n-5] & year==1999) | (rm~=rm[_n-6] & year==2000) | (rm~=rm[_n-7] & year==2001) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1994, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale-prime/laborstats/labmktexp-94-01.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1994, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale-prime/laborstats) name(labmktexp_94_01) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1994, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale-prime/laborstats) name(labmktexp_94_01_sd) fancy replace over nolog
restore


* METROPOLITAN MALES, LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if ano<1986 | ano>1993

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only workers with employment in metropolitan area on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm=="" ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1986 | (cnpj_radic==cnpj_radic[_n-1] & year==1987) | (cnpj_radic==cnpj_radic[_n-2] & year==1988) | (cnpj_radic==cnpj_radic[_n-3] & year==1989) | (cnpj_radic==cnpj_radic[_n-4] & year==1990) | (cnpj_radic==cnpj_radic[_n-5] & year==1991) | (cnpj_radic==cnpj_radic[_n-6] & year==1992) | (cnpj_radic==cnpj_radic[_n-7] & year==1993) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1987) | (rm==rm[_n-2] & year==1988) | (rm==rm[_n-3] & year==1989) | (rm==rm[_n-4] & year==1990) | (rm==rm[_n-5] & year==1991) | (rm==rm[_n-6] & year==1992) | (rm==rm[_n-7] & year==1993) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1987) | (rm~=rm[_n-2] & year==1988) | (rm~=rm[_n-3] & year==1989) | (rm~=rm[_n-4] & year==1990) | (rm~=rm[_n-5] & year==1991) | (rm~=rm[_n-6] & year==1992) | (rm~=rm[_n-7] & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1986 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1987) | (rm~=rm[_n-2] & year==1988) | (rm~=rm[_n-3] & year==1989) | (rm~=rm[_n-4] & year==1990) | (rm~=rm[_n-5] & year==1991) | (rm~=rm[_n-6] & year==1992) | (rm~=rm[_n-7] & year==1993) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale/laborstats/labmktexp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_86_93_sd) fancy replace over nolog
restore

* METROPOLITAN MALES, LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if ano<1990 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only workers with employment in metropolitan area on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm=="" ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1990 | (cnpj_radic==cnpj_radic[_n-1] & year==1991) | (cnpj_radic==cnpj_radic[_n-2] & year==1992) | (cnpj_radic==cnpj_radic[_n-3] & year==1993) | (cnpj_radic==cnpj_radic[_n-4] & year==1994) | (cnpj_radic==cnpj_radic[_n-5] & year==1995) | (cnpj_radic==cnpj_radic[_n-6] & year==1996) | (cnpj_radic==cnpj_radic[_n-7] & year==1997) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1991) | (rm==rm[_n-2] & year==1992) | (rm==rm[_n-3] & year==1993) | (rm==rm[_n-4] & year==1994) | (rm==rm[_n-5] & year==1995) | (rm==rm[_n-6] & year==1996) | (rm==rm[_n-7] & year==1997) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1991) | (rm~=rm[_n-2] & year==1992) | (rm~=rm[_n-3] & year==1993) | (rm~=rm[_n-4] & year==1994) | (rm~=rm[_n-5] & year==1995) | (rm~=rm[_n-6] & year==1996) | (rm~=rm[_n-7] & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1990 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1991) | (rm~=rm[_n-2] & year==1992) | (rm~=rm[_n-3] & year==1993) | (rm~=rm[_n-4] & year==1994) | (rm~=rm[_n-5] & year==1995) | (rm~=rm[_n-6] & year==1996) | (rm~=rm[_n-7] & year==1997) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale/laborstats/labmktexp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_90_97_sd) fancy replace over nolog
restore

* METROPOLITAN MALES, LABOR MARKET EXPERIENCE 1994-2001

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if ano<1994 | ano>2001

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only workers with employment in metropolitan area on Dec 31, 1994
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm=="" ) & ano==1994 )  // mark worker 1994 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1994 | (cnpj_radic==cnpj_radic[_n-1] & year==1995) | (cnpj_radic==cnpj_radic[_n-2] & year==1996) | (cnpj_radic==cnpj_radic[_n-3] & year==1997) | (cnpj_radic==cnpj_radic[_n-4] & year==1998) | (cnpj_radic==cnpj_radic[_n-5] & year==1999) | (cnpj_radic==cnpj_radic[_n-6] & year==2000) | (cnpj_radic==cnpj_radic[_n-7] & year==2001) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1995) | (rm==rm[_n-2] & year==1996) | (rm==rm[_n-3] & year==1997) | (rm==rm[_n-4] & year==1998) | (rm==rm[_n-5] & year==1999) | (rm==rm[_n-6] & year==2000) | (rm==rm[_n-7] & year==2001) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1995) | (rm~=rm[_n-2] & year==1996) | (rm~=rm[_n-3] & year==1997) | (rm~=rm[_n-4] & year==1998) | (rm~=rm[_n-5] & year==1999) | (rm~=rm[_n-6] & year==2000) | (rm~=rm[_n-7] & year==2001) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1994 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1995) | (rm~=rm[_n-2] & year==1996) | (rm~=rm[_n-3] & year==1997) | (rm~=rm[_n-4] & year==1998) | (rm~=rm[_n-5] & year==1999) | (rm~=rm[_n-6] & year==2000) | (rm~=rm[_n-7] & year==2001) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1994, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale/laborstats/labmktexp-94-01.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1994, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_94_01) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1994, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_94_01_sd) fancy replace over nolog
restore

* SAO PAULO CITY MALES, LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if ano<1986 | ano>1993

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only workers with employment in Sao Paulo city on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm~="007" ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1986 | (cnpj_radic==cnpj_radic[_n-1] & year==1987) | (cnpj_radic==cnpj_radic[_n-2] & year==1988) | (cnpj_radic==cnpj_radic[_n-3] & year==1989) | (cnpj_radic==cnpj_radic[_n-4] & year==1990) | (cnpj_radic==cnpj_radic[_n-5] & year==1991) | (cnpj_radic==cnpj_radic[_n-6] & year==1992) | (cnpj_radic==cnpj_radic[_n-7] & year==1993) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1987) | (rm==rm[_n-2] & year==1988) | (rm==rm[_n-3] & year==1989) | (rm==rm[_n-4] & year==1990) | (rm==rm[_n-5] & year==1991) | (rm==rm[_n-6] & year==1992) | (rm==rm[_n-7] & year==1993) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1987) | (rm~=rm[_n-2] & year==1988) | (rm~=rm[_n-3] & year==1989) | (rm~=rm[_n-4] & year==1990) | (rm~=rm[_n-5] & year==1991) | (rm~=rm[_n-6] & year==1992) | (rm~=rm[_n-7] & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1986 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1987) | (rm~=rm[_n-2] & year==1988) | (rm~=rm[_n-3] & year==1989) | (rm~=rm[_n-4] & year==1990) | (rm~=rm[_n-5] & year==1991) | (rm~=rm[_n-6] & year==1992) | (rm~=rm[_n-7] & year==1993) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in Sao Paulo city") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale/laborstats/labmktexp-sp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_sp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_sp_86_93_sd) fancy replace over nolog
restore

* SAO PAULO CITY MALES, LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if ano<1990 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid ano
drop _fillin

* keep only workers with employment in Sao Paulo city on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | rm~="007" ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1990 | (cnpj_radic==cnpj_radic[_n-1] & year==1991) | (cnpj_radic==cnpj_radic[_n-2] & year==1992) | (cnpj_radic==cnpj_radic[_n-3] & year==1993) | (cnpj_radic==cnpj_radic[_n-4] & year==1994) | (cnpj_radic==cnpj_radic[_n-5] & year==1995) | (cnpj_radic==cnpj_radic[_n-6] & year==1996) | (cnpj_radic==cnpj_radic[_n-7] & year==1997) )
* different firm but same metropolitan area
by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & ( (rm==rm[_n-1] & year==1991) | (rm==rm[_n-2] & year==1992) | (rm==rm[_n-3] & year==1993) | (rm==rm[_n-4] & year==1994) | (rm==rm[_n-5] & year==1995) | (rm==rm[_n-6] & year==1996) | (rm==rm[_n-7] & year==1997) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1991) | (rm~=rm[_n-2] & year==1992) | (rm~=rm[_n-3] & year==1993) | (rm~=rm[_n-4] & year==1994) | (rm~=rm[_n-5] & year==1995) | (rm~=rm[_n-6] & year==1996) | (rm~=rm[_n-7] & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1990 & indsamemet==0 & cnpj_radic~=. & ( (rm~=rm[_n-1] & year==1991) | (rm~=rm[_n-2] & year==1992) | (rm~=rm[_n-3] & year==1993) | (rm~=rm[_n-4] & year==1994) | (rm~=rm[_n-5] & year==1995) | (rm~=rm[_n-6] & year==1996) | (rm~=rm[_n-7] & year==1997) ) )
drop _chk _retiryr _deathyr fx_etaria rm cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsamemet indothrmun indunacc if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in Sao Paulo city") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/metromale/laborstats/labmktexp-sp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_sp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/metromale/laborstats) name(labmktexp_sp_90_97_sd) fancy replace over nolog
restore


// RAIS: NATIONAL 1-PERCENT SAMPLE

* NATIONAL PRIME-AGE MALES, ANNUAL LABOR MARKET TRANSITIONS 1986-97

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1986 | ano>1997
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators by year
mat labmkttrns_86_98_tbl = J(6,5,.)
matrix colnames labmkttrns_86_98_tbl = indsamefrm indsamemet indothrmun indretired indunacc
preserve
local yrrow 0
foreach year in 1986 1988 1990 1992 1994 1996 {
  local yrrow = `yrrow' + 1
  matname labmkttrns_86_98_tbl `year', rows(`yrrow') explicit
  restore, preserve
  keep if year==`year' | year==`year'+1
  gen int _retires = year if caus_desl_tc==7
  gen int _dies = year if caus_desl_tc==8
  egen int _retiryr = min(_retires), by(wid)
  egen int _deathyr = min(_dies), by(wid)
  drop _retires _dies caus_desl_tc
  // mutually exclusive and exhaustive labor market experience indicators
  * same firm, including regional transfers
  by wid: gen byte indsamefrm = ( year==`year' | (cnpj_radic==cnpj_radic[_n-1] & year==`year'+1) )
  * different firm but same metropolitan area
  by wid: gen byte indsamemet = ( indsamefrm==0 & cnpj_radic~=. & (uf==uf[_n-1] & year==`year'+1) ) 
  * different firm and different metropolitan area, excludes regional transfers within firm
  by wid: gen byte indothrmun = ( indsamefrm==0 & indsamemet==0 & cnpj_radic~=. & (uf~=uf[_n-1] & year==`year'+1) )
  * no employment, but prior retirement or death reported, or worker past retirement age in last observed job
  by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 ) ) )
  * unaccounted
  by wid: gen byte indunacc = ( indsamefrm==0 & indsamemet==0 & indothrmun==0 & indretired==0 )
  egen _chk = rsum(ind*)
  qui count if _chk~=1
  if `r(N)'>0  STOP  // indicators not mutually exclusive
  foreach var in indsamefrm indsamemet indothrmun indretired indunacc {
    qui summ `var', meanonly
    mat labmkttrns_86_98_tbl[`yrrow',colnumb(labmkttrns_86_98_tbl,"`var'")]=`r(mean)'
    }
  }
restore
matsave labmkttrns_86_98_tbl, p(brazrloc/tex/v4/natl-maleprime/laborstats) replace dropall
gen int year = real(_rowname)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = _rowname + "-`yr1'" if _rowname=="19`yr'"
  }
order year

* report
graph bar (mean) indsamefrm indsamemet indothrmun indunacc, over(_rowname) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same metro area") label(3 "Employed in other region") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/labmkttrns-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind*, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labmkttrns_86_98) fancy replace over nolog
restore

* NATIONAL PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1986 | ano>1993
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf==. | fx_etaria>7 ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1986 | (cnpj_radic==cnpj_radic[_n-1] & year==1987) | (cnpj_radic==cnpj_radic[_n-2] & year==1988) | (cnpj_radic==cnpj_radic[_n-3] & year==1989) | (cnpj_radic==cnpj_radic[_n-4] & year==1990) | (cnpj_radic==cnpj_radic[_n-5] & year==1991) | (cnpj_radic==cnpj_radic[_n-6] & year==1992) | (cnpj_radic==cnpj_radic[_n-7] & year==1993) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1987) | (uf==uf[_n-2] & year==1988) | (uf==uf[_n-3] & year==1989) | (uf==uf[_n-4] & year==1990) | (uf==uf[_n-5] & year==1991) | (uf==uf[_n-6] & year==1992) | (uf==uf[_n-7] & year==1993) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1987) | (uf~=uf[_n-2] & year==1988) | (uf~=uf[_n-3] & year==1989) | (uf~=uf[_n-4] & year==1990) | (uf~=uf[_n-5] & year==1991) | (uf~=uf[_n-6] & year==1992) | (uf~=uf[_n-7] & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1986 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1987) | (uf~=uf[_n-2] & year==1988) | (uf~=uf[_n-3] & year==1989) | (uf~=uf[_n-4] & year==1990) | (uf~=uf[_n-5] & year==1991) | (uf~=uf[_n-6] & year==1992) | (uf~=uf[_n-7] & year==1993) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/labmktexp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labmktexp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labmktexp_86_93_sd) fancy replace over nolog
restore

* NATIONAL PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1990 | ano>1997
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf==. | fx_etaria>7 ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1990 | (cnpj_radic==cnpj_radic[_n-1] & year==1991) | (cnpj_radic==cnpj_radic[_n-2] & year==1992) | (cnpj_radic==cnpj_radic[_n-3] & year==1993) | (cnpj_radic==cnpj_radic[_n-4] & year==1994) | (cnpj_radic==cnpj_radic[_n-5] & year==1995) | (cnpj_radic==cnpj_radic[_n-6] & year==1996) | (cnpj_radic==cnpj_radic[_n-7] & year==1997) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1991) | (uf==uf[_n-2] & year==1992) | (uf==uf[_n-3] & year==1993) | (uf==uf[_n-4] & year==1994) | (uf==uf[_n-5] & year==1995) | (uf==uf[_n-6] & year==1996) | (uf==uf[_n-7] & year==1997) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1991) | (uf~=uf[_n-2] & year==1992) | (uf~=uf[_n-3] & year==1993) | (uf~=uf[_n-4] & year==1994) | (uf~=uf[_n-5] & year==1995) | (uf~=uf[_n-6] & year==1996) | (uf~=uf[_n-7] & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1990 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1991) | (uf~=uf[_n-2] & year==1992) | (uf~=uf[_n-3] & year==1993) | (uf~=uf[_n-4] & year==1994) | (uf~=uf[_n-5] & year==1995) | (uf~=uf[_n-6] & year==1996) | (uf~=uf[_n-7] & year==1997) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/labmktexp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labmktexp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labmktexp_90_97_sd) fancy replace over nolog
restore

* NATIONAL PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1994-2001

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1994 | ano>2001
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1994
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf==. | fx_etaria>7 ) & ano==1994 )  // mark worker 1994 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1994 | (cnpj_radic==cnpj_radic[_n-1] & year==1995) | (cnpj_radic==cnpj_radic[_n-2] & year==1996) | (cnpj_radic==cnpj_radic[_n-3] & year==1997) | (cnpj_radic==cnpj_radic[_n-4] & year==1998) | (cnpj_radic==cnpj_radic[_n-5] & year==1999) | (cnpj_radic==cnpj_radic[_n-6] & year==2000) | (cnpj_radic==cnpj_radic[_n-7] & year==2001) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1995) | (uf==uf[_n-2] & year==1996) | (uf==uf[_n-3] & year==1997) | (uf==uf[_n-4] & year==1998) | (uf==uf[_n-5] & year==1999) | (uf==uf[_n-6] & year==2000) | (uf==uf[_n-7] & year==2001) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1995) | (uf~=uf[_n-2] & year==1996) | (uf~=uf[_n-3] & year==1997) | (uf~=uf[_n-4] & year==1998) | (uf~=uf[_n-5] & year==1999) | (uf~=uf[_n-6] & year==2000) | (uf~=uf[_n-7] & year==2001) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1994 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1995) | (uf~=uf[_n-2] & year==1996) | (uf~=uf[_n-3] & year==1997) | (uf~=uf[_n-4] & year==1998) | (uf~=uf[_n-5] & year==1999) | (uf~=uf[_n-6] & year==2000) | (uf~=uf[_n-7] & year==2001) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1994, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/labmktexp-94-01.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1994, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labmktexp_94_01) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1994, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labmktexp_94_01_sd) fancy replace over nolog
restore


* NATIONAL LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1986 | ano>1993

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep workers with employment on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf==. ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1986 | (cnpj_radic==cnpj_radic[_n-1] & year==1987) | (cnpj_radic==cnpj_radic[_n-2] & year==1988) | (cnpj_radic==cnpj_radic[_n-3] & year==1989) | (cnpj_radic==cnpj_radic[_n-4] & year==1990) | (cnpj_radic==cnpj_radic[_n-5] & year==1991) | (cnpj_radic==cnpj_radic[_n-6] & year==1992) | (cnpj_radic==cnpj_radic[_n-7] & year==1993) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1987) | (uf==uf[_n-2] & year==1988) | (uf==uf[_n-3] & year==1989) | (uf==uf[_n-4] & year==1990) | (uf==uf[_n-5] & year==1991) | (uf==uf[_n-6] & year==1992) | (uf==uf[_n-7] & year==1993) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1987) | (uf~=uf[_n-2] & year==1988) | (uf~=uf[_n-3] & year==1989) | (uf~=uf[_n-4] & year==1990) | (uf~=uf[_n-5] & year==1991) | (uf~=uf[_n-6] & year==1992) | (uf~=uf[_n-7] & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1986 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1987) | (uf~=uf[_n-2] & year==1988) | (uf~=uf[_n-3] & year==1989) | (uf~=uf[_n-4] & year==1990) | (uf~=uf[_n-5] & year==1991) | (uf~=uf[_n-6] & year==1992) | (uf~=uf[_n-7] & year==1993) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/labmktexp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_86_93_sd) fancy replace over nolog
restore

* NATIONAL LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1990 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep workers with employment on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf==. ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1990 | (cnpj_radic==cnpj_radic[_n-1] & year==1991) | (cnpj_radic==cnpj_radic[_n-2] & year==1992) | (cnpj_radic==cnpj_radic[_n-3] & year==1993) | (cnpj_radic==cnpj_radic[_n-4] & year==1994) | (cnpj_radic==cnpj_radic[_n-5] & year==1995) | (cnpj_radic==cnpj_radic[_n-6] & year==1996) | (cnpj_radic==cnpj_radic[_n-7] & year==1997) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1991) | (uf==uf[_n-2] & year==1992) | (uf==uf[_n-3] & year==1993) | (uf==uf[_n-4] & year==1994) | (uf==uf[_n-5] & year==1995) | (uf==uf[_n-6] & year==1996) | (uf==uf[_n-7] & year==1997) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1991) | (uf~=uf[_n-2] & year==1992) | (uf~=uf[_n-3] & year==1993) | (uf~=uf[_n-4] & year==1994) | (uf~=uf[_n-5] & year==1995) | (uf~=uf[_n-6] & year==1996) | (uf~=uf[_n-7] & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1990 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1991) | (uf~=uf[_n-2] & year==1992) | (uf~=uf[_n-3] & year==1993) | (uf~=uf[_n-4] & year==1994) | (uf~=uf[_n-5] & year==1995) | (uf~=uf[_n-6] & year==1996) | (uf~=uf[_n-7] & year==1997) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/labmktexp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_90_97_sd) fancy replace over nolog
restore

* NATIONAL LABOR MARKET EXPERIENCE 1994-01

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1994 | ano>2001

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep workers with employment on Dec 31, 1994
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf==. ) & ano==1994 )  // mark worker 1994 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1994 | (cnpj_radic==cnpj_radic[_n-1] & year==1995) | (cnpj_radic==cnpj_radic[_n-2] & year==1996) | (cnpj_radic==cnpj_radic[_n-3] & year==1997) | (cnpj_radic==cnpj_radic[_n-4] & year==1998) | (cnpj_radic==cnpj_radic[_n-5] & year==1999) | (cnpj_radic==cnpj_radic[_n-6] & year==2000) | (cnpj_radic==cnpj_radic[_n-7] & year==2001) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1995) | (uf==uf[_n-2] & year==1996) | (uf==uf[_n-3] & year==1997) | (uf==uf[_n-4] & year==1998) | (uf==uf[_n-5] & year==1999) | (uf==uf[_n-6] & year==2000) | (uf==uf[_n-7] & year==2001) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1995) | (uf~=uf[_n-2] & year==1996) | (uf~=uf[_n-3] & year==1997) | (uf~=uf[_n-4] & year==1998) | (uf~=uf[_n-5] & year==1999) | (uf~=uf[_n-6] & year==2000) | (uf~=uf[_n-7] & year==2001) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1994 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1995) | (uf~=uf[_n-2] & year==1996) | (uf~=uf[_n-3] & year==1997) | (uf~=uf[_n-4] & year==1998) | (uf~=uf[_n-5] & year==1999) | (uf~=uf[_n-6] & year==2000) | (uf~=uf[_n-7] & year==2001) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1994, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in same state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/labmktexp-94-01.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1994, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_94_01) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1994, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_94_01_sd) fancy replace over nolog
restore


* SAO PAULO STATE LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1986 | ano>1993

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep workers with employment in Sao Paulo state on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf~=35 ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1986 | (cnpj_radic==cnpj_radic[_n-1] & year==1987) | (cnpj_radic==cnpj_radic[_n-2] & year==1988) | (cnpj_radic==cnpj_radic[_n-3] & year==1989) | (cnpj_radic==cnpj_radic[_n-4] & year==1990) | (cnpj_radic==cnpj_radic[_n-5] & year==1991) | (cnpj_radic==cnpj_radic[_n-6] & year==1992) | (cnpj_radic==cnpj_radic[_n-7] & year==1993) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1987) | (uf==uf[_n-2] & year==1988) | (uf==uf[_n-3] & year==1989) | (uf==uf[_n-4] & year==1990) | (uf==uf[_n-5] & year==1991) | (uf==uf[_n-6] & year==1992) | (uf==uf[_n-7] & year==1993) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1987) | (uf~=uf[_n-2] & year==1988) | (uf~=uf[_n-3] & year==1989) | (uf~=uf[_n-4] & year==1990) | (uf~=uf[_n-5] & year==1991) | (uf~=uf[_n-6] & year==1992) | (uf~=uf[_n-7] & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1986 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1987) | (uf~=uf[_n-2] & year==1988) | (uf~=uf[_n-3] & year==1989) | (uf~=uf[_n-4] & year==1990) | (uf~=uf[_n-5] & year==1991) | (uf~=uf[_n-6] & year==1992) | (uf~=uf[_n-7] & year==1993) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in Sao Paulo state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/labmktexp-sp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_sp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_sp_86_93_sd) fancy replace over nolog
restore

* SAO PAULO STATE LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc municipio mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1990 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* identify federal states and fillin worker panels
gen byte uf = int(municipio/10000)
drop municipio
fillin wid ano
drop _fillin

* keep workers with employment in Sao Paulo state on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | uf~=35 ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
rename ano year
sort wid year

* labor market experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive labor market experience indicators
* same firm, including regional transfers
by wid: gen byte indsamefrm = ( year==1990 | (cnpj_radic==cnpj_radic[_n-1] & year==1991) | (cnpj_radic==cnpj_radic[_n-2] & year==1992) | (cnpj_radic==cnpj_radic[_n-3] & year==1993) | (cnpj_radic==cnpj_radic[_n-4] & year==1994) | (cnpj_radic==cnpj_radic[_n-5] & year==1995) | (cnpj_radic==cnpj_radic[_n-6] & year==1996) | (cnpj_radic==cnpj_radic[_n-7] & year==1997) )
* different firm but same metropolitan area
by wid: gen byte indsameuf = ( indsamefrm==0 & cnpj_radic~=. & ( (uf==uf[_n-1] & year==1991) | (uf==uf[_n-2] & year==1992) | (uf==uf[_n-3] & year==1993) | (uf==uf[_n-4] & year==1994) | (uf==uf[_n-5] & year==1995) | (uf==uf[_n-6] & year==1996) | (uf==uf[_n-7] & year==1997) ) )
* different firm and different metropolitan area, excludes regional transfers within firm
by wid: gen byte indothruf = ( indsamefrm==0 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1991) | (uf~=uf[_n-2] & year==1992) | (uf~=uf[_n-3] & year==1993) | (uf~=uf[_n-4] & year==1994) | (uf~=uf[_n-5] & year==1995) | (uf~=uf[_n-6] & year==1996) | (uf~=uf[_n-7] & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamefrm==0 & indsameuf==0 & indothruf==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive
// additional, non-exclusive labor market experience indicators
* regional transfers among indsamefrm==1 [not mutually exclusive]
by wid: gen byte indtransfer = ( indsamefrm==1 & year>1990 & indsameuf==0 & cnpj_radic~=. & ( (uf~=uf[_n-1] & year==1991) | (uf~=uf[_n-2] & year==1992) | (uf~=uf[_n-3] & year==1993) | (uf~=uf[_n-4] & year==1994) | (uf~=uf[_n-5] & year==1995) | (uf~=uf[_n-6] & year==1996) | (uf~=uf[_n-7] & year==1997) ) )
drop _chk _retiryr _deathyr fx_etaria uf cnpj_radic

* report
summ ind*
graph bar (mean) indsamefrm indsameuf indothruf indunacc if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed at same firm") label(2 "Employed in Sao Paulo state") label(3 "Employed in other state") label(4 "Unaccounted") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/labmktexp-sp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_sp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labmktexp_sp_90_97_sd) fancy replace over nolog
restore


log close
