version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/metromale-prime"

capture log close
log using "brazrloc/logs/employment-metromale-prime-subsibge.log", replace

local focallst "subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf"
local addlst   "subs_balcadv_indexp subs_balcadv_indexp_tarf"
local nberlst  "firm_indexp firm_indexp_tarf"
local cntrlsec "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlwkf "plant_lnempl plant_tenuryr plant_indprof plant_indtech plant_indwhit plant_indsklb"
local addlwkf  "plant_indprim plant_indhigh" 
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam subs_ppioecd subs_ppiworld"  // note additional IVs subs_ppioecd subs_ppiworld (to keep expiv from iv list)
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"


* SUBSECTOR IBGE VARIABLES, EMPLOYERS OF BRAZILIAN PRIME-AGE MALES
*-----------------------------------------------------------------
* Years 1990-1998

capture confirm file "brazrloc/data/employment-metromale-prime-subsibge.dta"
if _rc ~= 0 {
use identificad ano n_pis indprim indhigh indprof indtech indwhit indsklb temp_empr mod_subs_ibge if ano>=1990 & ano<=1998 using "brazrloc/data/rais-cnpj-data-metro-nber.dta", clear
rename ano year
sort identificad year 
rename mod_subs_ibge subs_ibge

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.
drop if subs_ibge==.

* future employment change
sort identificad year
by identificad: gen emplchg = n_pis[_n+1] - n_pis
label var emplchg "Employment Change over next year"
order identificad year emplchg

// SECTOR VARIABLES, MAPPING WITH SUBS_IBGE

* merge aggregate sector and comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balarank
rename subsibge subs_ibge
rename balcadv subs_balcadv

* merge additional sector information
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-moredata", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb

* reset private-job share before 1995 to 1995
replace subs_indprown_pis = subs_indprown_pis_95 if subs_indprown_pis==.
drop subs_indprown_pis_95

// FIRM VARIABLES

* switch to firm level (firm ID)
gen long cnpj_radic = int(identificad/1000000)
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"
order identificad cnpj_radic year emplchg

* merge export status information by firm
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year
rename indexp firm_indexp

* merge PIA information
rename cnpj_radic firm
sort firm year
merge firm year using "brazrloc/data/pia-data"
tab _m
drop if _m==2
drop firm_lntfp firm_ln_cap_empl _m
iis, clear
tis, clear
tsset, clear
rename firm cnpj_radic

* tenure
gen tenuryr = real(subinstr(temp_empr,",",".",.))/52
label var tenuryr "Tenure at plant (in years)"

// ANNUAL VARIABLES

* exporting status instruments
sort year
merge year using "brazrloc/auxil/wtf-data", nokeep
count if _m~=3
if `r(N)' > 0  STOP  // years incomplete in wtf-data.dta
drop _m

* plant size
gen lnempl = log(n_pis)
label var lnempl "Log Plant Employment"
drop n_pis

// FINALIZE ESTIMATION SAMPLE

drop cnpj_radic
sort identificad year

* rename plant level variables
foreach var in lnempl tenuryr indprof indtech indwhit indsklb indprim indhigh {
  rename `var' plant_`var'
  }

* interaction variables and dummies
gen subs_balcadv_tarf = subs_balcadv * subs_tarfoutp
label var subs_balcadv_tarf "subs_balcadv * subs_tarfoutp"
gen firm_indexp_tarf = firm_indexp * subs_tarfoutp
label var firm_indexp_tarf "firm_indexp * subs_tarfoutp"
gen subs_balcadv_indexp = subs_balcadv * firm_indexp
label var subs_balcadv_indexp "subs_balcadv * firm_indexp"
gen subs_balcadv_indexp_tarf = subs_balcadv * subs_tarfoutp * firm_indexp
label var subs_balcadv_indexp_tarf "subs_balcad * _tarfout * _indexp"
qui tab year, generate(indyr_)
qui tab subs_ibge, generate(indsubs_) nolab
drop subs_ibge

drop if year>=1998  // future change for year 1998 not well defined
forvalues year = 1998(-1)1990 {
  local i = `year'-1989
  local j = `year'-1989+4
  rename indyr_`i' indyr_`j'  // conformability with denomination in other regressions
  }

iis identificad
tis year
* xtdes

order identificad year emplchg subs_balcadv* subs_fdiflw subs_reffpen subs_tarfoutp subs_tarfintm subs_herfsale subs_indprown_pis firm_indexp* firm_lnlp plant_lnempl plant_tenuryr plant_indprof plant_indtech plant_indwhit plant_indsklb plant_indprim plant_indhigh subs_dollar subs_ppieu subs_ppinam subs_ppioecd subs_ppiworld subs_secrealx
save "brazrloc/data/employment-metromale-prime-subsibge.dta", replace
}

else use "brazrloc/data/employment-metromale-prime-subsibge.dta", clear

* 20-percent pseudo-random sampling
* qui count
* local startid = int(`r(N)'/5)
* local endid = `startid'*2
* keep in `startid'/`endid'
* codebook identificad


* IV REGRESSIONS: FIRST STAGE

local rnd 0
foreach depvar in `endog' {
  local rnd = `rnd' + 1
  reg `depvar' subs_balcadv `baseiv' `cntrlsec' `cntrlwkf'
  * xtreg `depvar' subs_balcadv `baseiv' `cntrlsec' `cntrlwkf', fe /*cluster(identificad) robust*/
  if `rnd'==1  est2vec subs_empl_iv1st, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc firm_lnlp plant_lnempl plant_tenuryr plant_indprof plant_indtech plant_indwhit plant_indsklb plant_indunsklb plant_indprim plant_indhigh plant_indscoll plant_indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam subs_ppioecd subs_ppiworld imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) name(`depvar')
  else         est2vec subs_empl_iv1st, addto(subs_empl_iv1st) name(`depvar')
  test `baseiv'
  if `rnd'==1  est2vec subs_empl_iv1st, r(F p df df_r) name(`depvar')
  else         est2vec subs_empl_iv1st, raddto(subs_empl_iv1st) name(`depvar')
  predict prd_`depvar', xb
  label var prd_`depvar' "OLS prediction: `depvar'"
  predict res_`depvar', residuals
  label var res_`depvar' "OLS residuals: `depvar'"
  }
reg firm_indexp subs_balcadv `expiv' `cntrlsec'
* xtreg firm_indexp subs_balcadv `expiv' `cntrlsec', fe /*cluster(identificad) robust*/
est2vec subs_empl_iv1st, addto(subs_empl_iv1st) name(firm_indexp_expiv)
test `expiv'
est2vec subs_empl_iv1st, raddto(subs_empl_iv1st) name(firm_indexp_expiv)
reg firm_indexp subs_balcadv `baseiv' `cntrlsec'
* xtreg firm_indexp subs_balcadv `baseiv' `cntrlsec', fe /*cluster(identificad) robust*/
est2vec subs_empl_iv1st, addto(subs_empl_iv1st) name(firm_indexp_baseiv)
test `baseiv'
est2vec subs_empl_iv1st, raddto(subs_empl_iv1st) name(firm_indexp_baseiv)
predict prd_indexp, xb
label var prd_indexp "OLS baseiv prediction: indexp"
predict res_indexp, residuals
label var res_indexp "OLS baseiv residuals: indexp"
preserve
  keep identificad year firm_indexp `focallst' `expiv' `cntrlsec'
  sort identificad year
  by identificad year: keep if _n==1
  reg firm_indexp subs_balcadv `expiv' `cntrlsec'
  * xtreg firm_indexp subs_balcadv `expiv' `cntrlsec', fe /*cluster(identificad) robust*/
  est2vec subs_empl_iv1st, addto(subs_empl_iv1st) name(firm_indexp_frmlvl)
  test `expiv'
  est2vec subs_empl_iv1st, raddto(subs_empl_iv1st) name(firm_indexp_frmlvl)
  reg firm_indexp subs_balcadv subs_balcadv_tarf `expiv' `cntrlsec'
  * xtreg firm_indexp subs_balcadv subs_balcadv_tarf `expiv' `cntrlsec', fe /*cluster(identificad) robust*/
  est2vec subs_empl_iv1st, addto(subs_empl_iv1st) name(firm_indexp_frmlvl_all)
  test `expiv'
  est2vec subs_empl_iv1st, raddto(subs_empl_iv1st) name(firm_indexp_frmlvl_all)
restore


* REGRESSIONS

// main regression

xtreg emplchg `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc firm_lnlp plant_lnempl plant_tenuryr plant_indprof plant_indtech plant_indwhit plant_indsklb plant_indunsklb plant_indprim plant_indhigh plant_indscoll plant_indgrad indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam subs_ppioecd subs_ppiworld imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N F p df_m r2 r2_o r2_w) name(xtreg_focal)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtreg sample"
tab year if indsmpl

xtreg emplchg `focallst' `addlst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_all)

// nber main regression

xtreg emplchg `nberlst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_nber_focal)

xtreg emplchg `nberlst' `addlst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_nber_all)

// comparisons with omitted focal variables

xtreg emplchg subs_balcadv firm_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_nointrct)

xtreg emplchg subs_balcadv `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_balcadv)

xtreg emplchg subs_balcadv subs_balcadv_tarf `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_balcadv_tarf)

xtreg emplchg firm_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_indexp)

xtreg emplchg firm_indexp firm_indexp_tarf subs_tarfoutp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_indexp_tarf)

xtreg emplchg subs_tarfoutp subs_tarfintm `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_aspme)

// xt comparison regressions

xtreg emplchg `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if indsmpl, fe /*cluster(identificad) robust*/  // different only if observations 1986-1989 loaded
est2vec subs_empl, addto(subs_empl) name(xtreg_ifxtreg)

xtreg emplchg `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg)

// ols comparison regressions

reg emplchg `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if indsmpl, cluster(identificad)
est2vec subs_empl, addto(subs_empl) name(ols_ifxtreg)

reg emplchg `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, cluster(identificad)
est2vec subs_empl, addto(subs_empl) name(ols)

reg emplchg subs_balcadv firm_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, cluster(identificad)
est2vec subs_empl, addto(subs_empl) name(ols_nointrct)

// robustness checks

xtreg emplchg subs_balcadv subs_balcadv_tarf `endog' `cntrlsec' `cntrlwkf' indyr*, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_allyrs)

xtreg emplchg `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_nofocal)

xtreg emplchg `focallst' `endog' `cntrlsec' `cntrlwkf' indyr* indsubs* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_indsubs)

xtreg emplchg `focallst' subs_indprown_pis `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_indprown)

xtreg emplchg `focallst' firm_lnlp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_lnlp)

xtreg emplchg `focallst' `endog' `cntrlsec' `cntrlwkf' `addlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_addlwkf)

// iv

xtreg emplchg subs_balcadv firm_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_iv_tarfetc)

xtreg emplchg subs_balcadv prd_indexp res_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_iv_indexp)

xtreg emplchg subs_balcadv prd_indexp res_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_iv_all)

xtivreg emplchg subs_balcadv subs_balcadv_tarf `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtivreg)

xtivreg emplchg subs_balcadv `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtivreg_noexpiv)

xtivreg emplchg subs_balcadv `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtivreg_nointrct)

// nber iv

xtreg emplchg firm_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_nberiv_tarfetc)

xtreg emplchg prd_indexp res_indexp `endog' `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_nberiv_indexp)

xtreg emplchg prd_indexp res_indexp prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen `cntrlsec' `cntrlwkf' indyr* if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtreg_nberiv_all)

xtivreg emplchg `cntrlsec' `cntrlwkf' indyr* (firm_indexp firm_indexp_tarf `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtivreg_nber)

xtivreg emplchg subs_tarfintm subs_reffpen `cntrlsec' `cntrlwkf' indyr* (firm_indexp firm_indexp_tarf subs_tarfoutp = `baseiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtivreg_nber_noexpiv)

xtivreg emplchg `cntrlsec' `cntrlwkf' indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe /*cluster(identificad) robust*/
est2vec subs_empl, addto(subs_empl) name(xtivreg_nber_nointrct)


* SAVE RESULTS

preserve
foreach type in b se e {
  matsave subs_empl_`type', p(brazrloc/estmat/v4/reg/metromale-prime) t(double) replace dropall
  }
foreach type in b se e r {
  matsave subs_empl_iv1st_`type', p(brazrloc/estmat/v4/reg/metromale-prime) t(double) replace dropall
  }
restore
drop prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp indsmpl

log close

